pub enum Error {
UnknownModel,
UnknownKernel,
}Expand description
Errors that can occur when trying to identify the Raspberry Pi hardware.
Variants
UnknownModel
Unknown model.
DeviceInfo was unable to identify the Raspberry Pi model based on the
contents of /proc/cpuinfo, /sys/firmware/devicetree/base/compatible
and /sys/firmware/devicetree/base/model.
Support for new models is usually added shortly after they are officially announced and available to the public. Make sure you’re using the latest release of rpi-pal.
You may also encounter this error if your Linux distribution doesn’t provide any of the common user-accessible system files that are used to identify the model and SoC.
UnknownKernel
Unknown kernel.
KernelVersion needed to identify the kernel version from file
/proc/version, but was unable to either open the file or parse its
content.